pub struct ChatMessageHistory { /* private fields */ }Expand description
MemoryStore implementation backed by any Store.
Messages are stored under namespace ["memory", "{session_id}"] with key "messages".
Summaries (used by summary strategies) are stored under the same namespace with key "summary".
This replaces the old InMemoryStore (in-memory only) and FileChatMessageHistory
(file-only) with a single implementation that works with any Store backend
(InMemoryStore, FileStore, RedisStore, etc.).
Implementations
Sourceimpl ChatMessageHistory
impl ChatMessageHistory
Sourcepub fn new(store: Arc<dyn Store>) -> Self
pub fn new(store: Arc<dyn Store>) -> Self
Create a new ChatMessageHistory backed by the given store.
Sourcepub async fn get_summary(
&self,
session_id: &str,
) -> Result<Option<String>, SynapticError>
pub async fn get_summary( &self, session_id: &str, ) -> Result<Option<String>, SynapticError>
Get the summary for a session (used by summary memory strategies).
Sourcepub async fn set_summary(
&self,
session_id: &str,
summary: &str,
) -> Result<(), SynapticError>
pub async fn set_summary( &self, session_id: &str, summary: &str, ) -> Result<(), SynapticError>
Set the summary for a session (used by summary memory strategies).